@@ -9,30 +9,33 @@ from typing import Iterable
 from typing import List
 from typing import Optional
 from typing import Tuple
-from typing import Type
 
 from aiohttp import ClientResponseError
 from fastapi.encoders import jsonable_encoder
 from pydantic import AnyHttpUrl
 from ramodels.mo import Employee
+from ramodels.mo import FacetClass
 from ramodels.mo import OrganisationUnit
 from ramodels.mo._shared import MOBase
 from ramodels.mo.details import Address
 from ramodels.mo.details import Engagement
 from ramodels.mo.details import EngagementAssociation
+from ramodels.mo.details import ITUser
 from ramodels.mo.details import Manager
 
 from raclients.modelclientbase import ModelClientBase
 
 
 class ModelClient(ModelClientBase):
-    __mo_path_map = {
+    __mo_path_map: Dict[MOBase, str] = {
         OrganisationUnit: "/service/ou/create",
         Employee: "/service/e/create",
         Engagement: "/service/details/create",
+        ITUser: "/service/details/create",
         EngagementAssociation: "/service/details/create",
         Manager: "/service/details/create",
         Address: "/service/details/create",
+        FacetClass: "/service/f/{facet_uuid}/",
     }
 
     def __init__(
@@ -53,13 +56,13 @@ class ModelClient(ModelClientBase):
     def _get_path_map(self) -> Dict[MOBase, str]:
         return self.__mo_path_map
 
-    async def _post_single_to_backend(
-        self, current_type: Type[MOBase], obj: MOBase
-    ) -> Any:
+    async def _post_single_to_backend(self, current_type: MOBase, obj: MOBase) -> Any:
         session = await self._verify_session()
-        post_url = (
-            f"{self._base_url}{self.__mo_path_map[current_type]}?force={self.force}"
-        )
+        # Note that we additionally format the object's fields onto the path mapping to
+        # support schemes such as /service/f/{facet_uuid}/, where facet_uuid is
+        # retrieved from obj.facet_uuid.
+        path = self.__mo_path_map[current_type].format_map(obj.dict())
+        post_url = f"{self._base_url}{path}?force={self.force}"
 
         async with session.post(post_url, json=jsonable_encoder(obj)) as response:
             resp = await response.json()
